@@ -26,11 +26,13 @@ import numpy as np
 def ellps2axis(ellps_name):
     """Get semi-major and semi-minor axis from ellipsis definition
 
-    :Parameters:
+    Parameters
+    ---------
     ellps_name : str
         Standard name of ellipsis
 
-    :Returns:
+    Returns
+    -------
     (a, b) : semi-major and semi-minor axis
     """
 
@@ -89,13 +91,15 @@ def ellps2axis(ellps_name):
 def area_def2basemap(area_def, **kwargs):
     """Get Basemap object from AreaDefinition
 
-    :Parameters:
+    Parameters
+    ---------
     area_def : object
         geometry.AreaDefinition object
-    **kwargs: Keyword arguments
+    \*\*kwargs: Keyword arguments
         Additional initialization arguments for Basemap
 
-    :Returns:
+    Returns
+    -------
     bmap : Basemap object
     """
 
@@ -177,7 +181,8 @@ def show_quicklook(area_def, data, vmin=None, vmax=None,
                    num_parallels=10, coast_res='c'):
     """Display default quicklook plot
 
-    :Parameters:
+    Parameters
+    ---------
     area_def : object
         geometry.AreaDefinition object
     data : numpy array | numpy masked array
@@ -195,7 +200,8 @@ def show_quicklook(area_def, data, vmin=None, vmax=None,
     coast_res : {'c', 'l', 'i', 'h', 'f'}, optional
         Resolution of coastlines
 
-    :Returns:
+    Returns
+    -------
     bmap : Basemap object
     """
 
@@ -211,7 +217,8 @@ def save_quicklook(filename, area_def, data, vmin=None, vmax=None,
                    num_parallels=10, coast_res='c', backend='AGG'):
     """Display default quicklook plot
 
-    :Parameters:
+    Parameters
+    ----------
     filename : str
         path to output file
     area_def : object
